@@ -1,31 +1,48 @@
 package App::githook::perltidy::install;
 use strict;
 use warnings;
-use parent 'App::githook::perltidy';
-use File::Basename;
+use App::githook::perltidy::install_CI
+  isa => 'App::githook::perltidy',
+  has => {
+    absolute => {},
+    force    => {},
+  };
 use Path::Tiny;
 
-our $VERSION = '0.12.3';
+our $VERSION = '1.0.0';
 
 sub run {
     my $self = shift;
 
-    die ".perltidyrc not in repository.\n" unless $self->{perltidyrc};
-
-    my $hooks_dir = path( '.git', 'hooks' );
+    my $hooks_dir = $self->repo->child( '.git', 'hooks' );
     if ( !-d $hooks_dir ) {
         die "Directory not found: $hooks_dir\n";
     }
 
     my $pre_file = $hooks_dir->child('pre-commit');
     if ( -e $pre_file or -l $pre_file ) {
-        die "File/link exists: $pre_file\n" unless $self->{opts}->{force};
+        die "File/link exists: $pre_file\n" unless $self->force;
     }
 
-    $pre_file->spew("#!/bin/sh\n$0 pre-commit\n");
+    my $gp = path($0);
+    if ( $self->absolute ) {
+        $gp = $gp->realpath;
+    }
+    else {
+        $gp = $gp->basename;
+    }
+
+    $pre_file->spew(
+        qq{#!/bin/sh
+if [ "\$NO_GITHOOK_PERLTIDY" != "1" ]; then
+    PERL5LIB="" $gp pre-commit
+fi
+}
+    );
     chmod 0755, $pre_file || warn "chmod: $!";
-    print "$self->{me}: $pre_file";
-    print " (forced)" if $self->{opts}->{force};
+    print $pre_file;
+    print " (forced)"   if $self->force;
+    print " (absolute)" if $self->absolute;
     print "\n";
 }
 
@@ -38,7 +55,7 @@ App::githook::perltidy::install - install git hooks
 
 =head1 VERSION
 
-0.12.3 (2018-11-22)
+1.0.0 (2022-10-14)
 
 =head1 SEE ALSO
 
@@ -50,7 +67,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2011-2018 Mark Lawrence <nomad@null.net>
+Copyright 2011-2022 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
